@@ -22,9 +22,9 @@
  
 #include "config.h"
 
-#include "galias.h"
 #include "glib.h"
 #include "gthreadinit.h"
+#include "galias.h"
 
 #if defined (__GNUC__)
 # if defined (G_ATOMIC_I486)
@@ -121,7 +121,7 @@ g_atomic_pointer_compare_and_exchange (gpointer *atomic,
 			: "=r" (result), "=m" (*a)
 			: "r" (oldval), "m" (*a), "r" (a),
 			"0" (newval));
-  return result != 0;
+  return result == oldval;
 }
 #  else /* What's that */
 #    error "Your system has an unsupported pointer size"
@@ -646,3 +646,6 @@ _g_atomic_thread_init (void)
   g_atomic_mutex = g_mutex_new ();
 #endif /* DEFINE_WITH_MUTEXES */
 }
+
+#define __G_ATOMIC_C__
+#include "galiasdef.c"
