@@ -399,14 +399,17 @@ open_converter (const gchar *to_codeset,
   G_UNLOCK (iconv_cache_lock);
   
   /* Something went wrong.  */
-  if (errno == EINVAL)
-    g_set_error (error, G_CONVERT_ERROR, G_CONVERT_ERROR_NO_CONVERSION,
-		 _("Conversion from character set '%s' to '%s' is not supported"),
-		 from_codeset, to_codeset);
-  else
-    g_set_error (error, G_CONVERT_ERROR, G_CONVERT_ERROR_FAILED,
-		 _("Could not open converter from '%s' to '%s'"),
-		 from_codeset, to_codeset);
+  if (error)
+    {
+      if (errno == EINVAL)
+	g_set_error (error, G_CONVERT_ERROR, G_CONVERT_ERROR_NO_CONVERSION,
+		     _("Conversion from character set '%s' to '%s' is not supported"),
+		     from_codeset, to_codeset);
+      else
+	g_set_error (error, G_CONVERT_ERROR, G_CONVERT_ERROR_FAILED,
+		     _("Could not open converter from '%s' to '%s'"),
+		     from_codeset, to_codeset);
+    }
   
   return cd;
 }
@@ -610,14 +613,16 @@ g_convert_with_iconv (const gchar *str,
 	    goto again;
 	  }
 	case EILSEQ:
-	  g_set_error (error, G_CONVERT_ERROR, G_CONVERT_ERROR_ILLEGAL_SEQUENCE,
-		       _("Invalid byte sequence in conversion input"));
+	  if (error)
+	    g_set_error (error, G_CONVERT_ERROR, G_CONVERT_ERROR_ILLEGAL_SEQUENCE,
+			 _("Invalid byte sequence in conversion input"));
 	  have_error = TRUE;
 	  break;
 	default:
-	  g_set_error (error, G_CONVERT_ERROR, G_CONVERT_ERROR_FAILED,
-		       _("Error during conversion: %s"),
-		       g_strerror (errno));
+	  if (error)
+	    g_set_error (error, G_CONVERT_ERROR, G_CONVERT_ERROR_FAILED,
+			 _("Error during conversion: %s"),
+			 g_strerror (errno));
 	  have_error = TRUE;
 	  break;
 	}
@@ -633,8 +638,9 @@ g_convert_with_iconv (const gchar *str,
 	{
           if (!have_error)
             {
-              g_set_error (error, G_CONVERT_ERROR, G_CONVERT_ERROR_PARTIAL_INPUT,
-                           _("Partial character sequence at end of input"));
+	      if (error)
+		g_set_error (error, G_CONVERT_ERROR, G_CONVERT_ERROR_PARTIAL_INPUT,
+			     _("Partial character sequence at end of input"));
               have_error = TRUE;
             }
 	}
@@ -1122,7 +1128,7 @@ g_get_filename_charsets (G_CONST_RETURN gchar ***filename_charsets)
 gboolean
 g_get_filename_charsets (G_CONST_RETURN gchar ***filename_charsets) 
 {
-  static gchar *charsets[] = {
+  static const gchar *charsets[] = {
     "UTF-8",
     NULL
   };
