@@ -610,10 +610,11 @@ parse_int (const gchar *arg_name,
 	   GError     **error)
 {
   gchar *end;
-  glong tmp = strtol (arg, &end, 0);
+  glong tmp; 
 
   errno = 0;
-  
+  tmp = strtol (arg, &end, 0);
+
   if (*arg == '\0' || *end != '\0')
     {
       g_set_error (error,
@@ -731,7 +732,7 @@ parse_arg (GOptionContext *context,
 
 	if (change->allocated.array.len == 0)
 	  {
-	    change->prev.array = entry->arg_data;
+	    change->prev.array = *(gchar ***)entry->arg_data;
 	    change->allocated.array.data = g_new (gchar *, 2);
 	  }
 	else
@@ -789,7 +790,7 @@ parse_arg (GOptionContext *context,
 
 	if (change->allocated.array.len == 0)
 	  {
-	    change->prev.array = entry->arg_data;
+	    change->prev.array = *(gchar ***)entry->arg_data;
 	    change->allocated.array.data = g_new (gchar *, 2);
 	  }
 	else
@@ -1168,7 +1169,7 @@ g_option_context_parse (GOptionContext   *context,
 	  gchar *arg, *dash;
 	  gboolean parsed = FALSE;
 
-	  if ((*argv)[i][0] == '-' && !stop_parsing)
+	  if ((*argv)[i][0] == '-' && (*argv)[i][1] != '\0' && !stop_parsing)
 	    {
 	      if ((*argv)[i][1] == '-')
 		{
