@@ -26,8 +26,8 @@
 
 #include "config.h"
 
-#include "galias.h"
 #include "glib.h"
+#include "galias.h"
 
 
 G_LOCK_DEFINE_STATIC (queue_memchunk);
@@ -1001,3 +1001,6 @@ g_queue_insert_sorted (GQueue           *queue,
   else
     g_queue_push_tail (queue, data);
 }
+
+#define __G_QUEUE_C__
+#include "galiasdef.c"
