@@ -43,11 +43,12 @@
 #include <signal.h>
 #endif
 
-#include "galias.h"
 #include "glib.h"
 #include "gprintf.h"
 #include "gprintfint.h"
 
+#include "galias.h"
+
 #ifdef G_OS_WIN32
 #include <windows.h>
 #endif
@@ -1965,6 +1966,9 @@ g_strcompress (const gchar *source)
 	  p++;
 	  switch (*p)
 	    {
+	    case '\0':
+	      g_warning ("g_strcompress: trailing \\");
+	      goto out;
 	    case '0':  case '1':  case '2':  case '3':  case '4':
 	    case '5':  case '6':  case '7':
 	      *q = 0;
@@ -2001,6 +2005,7 @@ g_strcompress (const gchar *source)
 	*q++ = *p;
       p++;
     }
+ out:
   *q = 0;
   
   return dest;
@@ -2727,3 +2732,6 @@ g_strv_length (gchar **str_array)
 
   return i;
 }
+
+#define __G_STRFUNCS_C__
+#include "galiasdef.c"
