@@ -29,7 +29,6 @@
  */
 
 #include "config.h"
-#include "galias.h"
 #include "glibconfig.h"
 
 #ifdef HAVE_UNISTD_H
@@ -47,13 +46,14 @@
 #endif /* G_OS_WIN32 */
 
 #include "glib.h"
+#include "galias.h"
 
 
 struct _GTimer
 {
 #ifdef G_OS_WIN32
-  DWORD start;
-  DWORD end;
+  guint64 start;
+  guint64 end;
 #else /* !G_OS_WIN32 */
   struct timeval start;
   struct timeval end;
@@ -64,7 +64,7 @@ struct _GTimer
 
 #ifdef G_OS_WIN32
 #  define GETTIME(v) \
-     v = GetTickCount ()
+     GetSystemTimeAsFileTime ((FILETIME *)&v)
 #else /* !G_OS_WIN32 */
 #  define GETTIME(v) \
      gettimeofday (&v, NULL)
@@ -123,7 +123,7 @@ void
 g_timer_continue (GTimer *timer)
 {
 #ifdef G_OS_WIN32
-  DWORD elapsed;
+  guint64 elapsed;
 #else
   struct timeval elapsed;
 #endif /* G_OS_WIN32 */
@@ -176,7 +176,9 @@ g_timer_elapsed (GTimer *timer,
 		 gulong *microseconds)
 {
   gdouble total;
-#ifndef G_OS_WIN32
+#ifdef G_OS_WIN32
+  gint64 elapsed;
+#else
   struct timeval elapsed;
 #endif /* G_OS_WIN32 */
 
@@ -184,23 +186,14 @@ g_timer_elapsed (GTimer *timer,
 
 #ifdef G_OS_WIN32
   if (timer->active)
-    timer->end = GetTickCount ();
+    GETTIME (timer->end);
 
-  /* Check for wraparound, which happens every 49.7 days. */
-  if (timer->end < timer->start)
-    total = (UINT_MAX - (timer->start - timer->end - 1)) / 1000.0;
-  else
-    total = (timer->end - timer->start) / 1000.0;
+  elapsed = timer->end - timer->start;
+
+  total = elapsed / 1e7;
 
   if (microseconds)
-    {
-      if (timer->end < timer->start)
-	*microseconds =
-	  ((UINT_MAX - (timer->start - timer->end - 1)) % 1000) * 1000;
-      else
-	*microseconds =
-	  ((timer->end - timer->start) % 1000) * 1000;
-    }
+    *microseconds = (elapsed / 10) % 1000000;
 #else /* !G_OS_WIN32 */
   if (timer->active)
     gettimeofday (&timer->end, NULL);
@@ -240,7 +233,7 @@ g_usleep (gulong microseconds)
   struct timespec request, remaining;
   request.tv_sec = microseconds / G_USEC_PER_SEC;
   request.tv_nsec = 1000 * (microseconds % G_USEC_PER_SEC);
-  while (nanosleep (&request, &remaining) == EINTR)
+  while (nanosleep (&request, &remaining) == -1 && errno == EINTR)
     request = remaining;
 # else /* !HAVE_NANOSLEEP */
   if (g_thread_supported ())
@@ -314,3 +307,6 @@ g_time_val_add (GTimeVal *time_, glong microseconds)
        }      
     }
 }
+
+#define __G_TIMER_C__
+#include "galiasdef.c"
