@@ -34,8 +34,9 @@ G_BEGIN_DECLS
 
 #ifdef G_OS_WIN32
 
-/* On native Win32, directory separator is the backslash, and search path
- * separator is the semicolon.
+/* On Win32, the canonical directory separator is the backslash, and
+ * the search path separator is the semicolon. Note that also the
+ * (forward) slash works as directory separator.
  */
 #define G_DIR_SEPARATOR '\\'
 #define G_DIR_SEPARATOR_S "\\"
@@ -94,6 +95,7 @@ G_BEGIN_DECLS
 #endif
 #ifdef G_IMPLEMENT_INLINES
 #  define G_INLINE_FUNC
+#  undef  G_CAN_INLINE
 #elif defined (__GNUC__) 
 #  define G_INLINE_FUNC extern inline
 #elif defined (G_CAN_INLINE) 
@@ -102,7 +104,7 @@ G_BEGIN_DECLS
 #  define G_INLINE_FUNC
 #endif /* !G_INLINE_FUNC */
 
-/* Retrive static string info
+/* Retrieve static string info
  */
 #ifdef G_OS_WIN32
 #define g_get_user_name g_get_user_name_utf8
@@ -366,24 +368,38 @@ G_END_DECLS
 #ifndef G_PLATFORM_WIN32
 # define G_WIN32_DLLMAIN_FOR_DLL_NAME(static, dll_name)
 #else
-# define G_WIN32_DLLMAIN_FOR_DLL_NAME(static, dll_name)			   \
-static char *dll_name;							   \
-									   \
-BOOL WINAPI								   \
-DllMain (HINSTANCE hinstDLL,						   \
-	 DWORD     fdwReason,						   \
-	 LPVOID    lpvReserved)						   \
-{									   \
-  char bfr[1000];							   \
-  switch (fdwReason)							   \
-    {									   \
-    case DLL_PROCESS_ATTACH:						   \
-      GetModuleFileName ((HMODULE) hinstDLL, bfr, sizeof (bfr));	   \
-      dll_name = g_path_get_basename (bfr);				   \
-      break;								   \
-    }									   \
-									   \
-  return TRUE;								   \
+# define G_WIN32_DLLMAIN_FOR_DLL_NAME(static, dll_name)			\
+static char *dll_name;							\
+									\
+BOOL WINAPI								\
+DllMain (HINSTANCE hinstDLL,						\
+	 DWORD     fdwReason,						\
+	 LPVOID    lpvReserved)						\
+{									\
+  wchar_t wcbfr[1000];							\
+  char cpbfr[1000];							\
+  char *tem;								\
+  switch (fdwReason)							\
+    {									\
+    case DLL_PROCESS_ATTACH:						\
+      if (GetVersion () < 0x80000000)					\
+	{								\
+	  GetModuleFileNameW ((HMODULE) hinstDLL, wcbfr, G_N_ELEMENTS (wcbfr));	\
+	  tem = g_utf16_to_utf8 (wcbfr, -1, NULL, NULL, NULL);		\
+	  dll_name = g_path_get_basename (tem);				\
+	  g_free (tem);							\
+	}								\
+      else								\
+	{								\
+	  GetModuleFileNameA ((HMODULE) hinstDLL, cpbfr, G_N_ELEMENTS (cpbfr));	\
+	  tem = g_locale_to_utf8 (cpbfr, -1, NULL, NULL, NULL);		\
+	  dll_name = g_path_get_basename (tem);				\
+	  g_free (tem);							\
+	}								\
+      break;								\
+    }									\
+									\
+  return TRUE;								\
 }
 #endif /* G_PLATFORM_WIN32 */
 
