@@ -24,6 +24,8 @@
 #include	"gclosure.h"
 #include	"gvaluecollector.h"
 
+#include	"gobjectalias.h"
+
 #include <string.h>
 
 /* --- typedefs & structures --- */
@@ -108,7 +110,7 @@ gstring_free (gpointer boxed)
 }
 
 void
-g_boxed_type_init (void)  /* sync with gtype.c */
+g_boxed_type_init (void) 
 {
   static const GTypeInfo info = {
     0,                          /* class_size */
@@ -528,3 +530,6 @@ g_value_take_boxed (GValue       *value,
 
   value_set_boxed_internal (value, boxed, FALSE, TRUE);
 }
+
+#define __G_BOXED_C__
+#include "gobjectaliasdef.c"
